<template>
	<div class="system-edit-user-container">
		<el-dialog title="查看审批流程" v-model="isShowDialog" width="60%" draggable :fullscreen="full">
			<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
			<el-row :gutter="35">
				<el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
					<el-table
						:data="tableData"
						style="width: 100%; margin-top: 15px"
						ref="multipleTableRef"
						:model="formInline"
						:header-cell-style="{ background: '#f6f7fa', color: '#909399' }"
					>
						<el-table-column prop="workName" label="审批人" show-overflow-tooltip sortable></el-table-column>
						<el-table-column prop="title" label="审批标题" show-overflow-tooltip sortable></el-table-column>
						<el-table-column prop="approvePersonName" label="编写人" show-overflow-tooltip sortable></el-table-column>
						<el-table-column prop="approveMemo" label="审批意见" show-overflow-tooltip sortable></el-table-column>
					</el-table>
				</el-col>
			</el-row>
			<div class="pages">
				<el-pagination
					v-if="tableData.length == 0 ? false : true"
					v-model:currentPage="pageIndex"
					v-model:page-size="pageSize"
					:page-sizes="[10, 20, 30]"
					:pager-count="5"
					class="mt15"
					background
					layout="total, sizes, prev, pager, next, jumper"
					:total="total"
					@size-change="onHandleSizeChange"
					@current-change="onHandleCurrentChange"
				/>
			</div>
			<template #footer>
				<span class="dialog-footer">
					<el-button @click="onCancel">取消</el-button>
				</span>
			</template>
		</el-dialog>
	</div>
</template>

<script lang="ts">
import { ref, reactive, defineComponent, onMounted } from 'vue';

import type { FormInstance } from 'element-plus';
import {
	// ElMessageBox,
	ElMessage,
} from 'element-plus';
import { Search, FullScreen } from '@element-plus/icons-vue';
import { emergencyPlanApi } from '../../../../api/contingencyManagement/emergencyPlan';
export default defineComponent({
	name: 'abolishLibrary',
	components: {},
	setup(prop, { emit }) {
		// 列表参数
		const listQuery = reactive({
			pageIndex: 1,
			pageSize: 10,
			searchParams: {
				relateType: 1,
				relateId: '',
				startTime: '',
				endTime: '',
			},
		});
		// 定义表格数据
		const tableData = ref([]);

		// 列表数据请求
		const uid = ref();
		const openDialog = async (id: number) => {
			isShowDialog.value = true;
      listQuery.searchParams.relateId=id
			uid.value = id;
			let res = await emergencyPlanApi().processEmergencyPlan(listQuery);
			if (res.data.code === '200') {
				tableData.value = res.data.data;
				pageIndex.value = res.data.pageIndex;
				pageSize.value = res.data.pageSize;
				total.value = res.data.total;
			} else {
				ElMessage({
					showClose: true,
					type: 'error',
					message: res.data.msg,
				});
			}
		};

		const isShowDialog = ref(false);

		const ruleFormRef = ref<FormInstance>();
		// 打开弹窗
		// const openDialog = () => {
		//   isShowDialog.value = true;
		// };
		// 关闭弹窗
		const closeDialog = () => {
			isShowDialog.value = false;
		};
		// 取消
		const onCancel = () => {
			closeDialog();
		};
		// 分页
		const pageIndex = ref();
		const pageSize = ref();
		const total = ref();
		// 分页改变
		const handleSizeChange = (val: number) => {
			listQuery.pageSize = val;
		};
		// 分页未改变
		const handleCurrentChange = (val: number) => {
			listQuery.pageIndex = val;
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		return {
			openDialog,
			closeDialog,
			isShowDialog,
			onCancel,
			tableData,
			Search,
			ruleFormRef,
			pageIndex,
			pageSize,
			handleSizeChange,
			handleCurrentChange,
			toggleFullscreen,
			FullScreen,
			full,
			listQuery,
			total,
			emit,
			uid,
		};
	},
});
</script>
<style scoped lang="scss">
.textarea {
	height: 168px !important;
}
.textarea ::v-deep .el-textarea__inner {
	height: 168px !important;
}
::v-deep .el-table__cell {
	font-weight: 400;
}
//分页
.pages {
	display: flex;
	justify-content: flex-end;
}
::v-deep .el-pagination .el-pager li {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination .el-pager li.is-active {
	background-color: #409eff;
	color: #fff;
}
::v-deep .el-pagination .btn-prev {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination button:disabled {
	color: #c0c4cc;
}
::v-deep .el-pagination .btn-next {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
</style>